Module counters

Module counters 

Objects and helpers for publishing metrics in an efficent manner.

Macros

increment
Increase the field given, by default incrementing by 1

Structs

AutoExportingMetrics
A wrapper around a Message class that adds periodic backup.
AutoExportingMetricsBuilder
A builder to help configure a metrics counter that exports regularly to redis

Traits

MetricMessage
Trait for metric messages being exported