pub struct Builder { /* private fields */ }Expand description
Utility class to simplify setting up a redis object
Implementations
Sourceimpl Builder
impl Builder
Sourcepub fn native_tls(self, native_tls: bool) -> Self
pub fn native_tls(self, native_tls: bool) -> Self
Set whether the connection being built should be configured
Sourcepub fn pubsub_prefix(self, pubsub_prefix: String) -> Self
pub fn pubsub_prefix(self, pubsub_prefix: String) -> Self
Set a prefix that should be applied to all pubsub listening and publishing. This is intended for namespacing pubsub operations for testing.
Sourcepub fn build(self) -> Result<Arc<RedisObjects>, ErrorTypes>
pub fn build(self) -> Result<Arc<RedisObjects>, ErrorTypes>
finalize the building process and create the redis object